eprllib.ActionFunctions.DualSetPointThermostat — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.ActionFunctions.DualSetPointThermostat

## Dual Set Point Thermostat

This module contains the implementation of the Dual Set Point Thermostat action function. The action function transforms the action values from [0,1] to the appropriate range for the actuator type (cooling, heating, or flow rate). The transformation is linear for cooling and heating, and linear for flow rate.

Classes

`DualSetPointThermostat`(action_fn_config) |